@@ -51,3 +51,18 @@ def addDays(targetDate, addDays: int):
 
     # 戻り値を返す
     return targetDate + datetime.timedelta(days=addDays)
+
+def getListMargeString(delimiter:str, targetList:list):
+
+    """ 
+    対象リストを特定の文字列で連結して返す
+    
+    Parameters
+    ----------
+    delimiter : str
+        デリミタ文字
+    targetList : list
+        対象リスト
+    """
+
+    return delimiter.join(targetList) if len(targetList) > 1 else targetList[0]
