@@ -1,9 +1,11 @@
 import os
+from socketserver import DatagramRequestHandler
 import pandas as pd
+from sqlalchemy import schema
 from sqlalchemy.sql.elements import Null
 import LibHanger.Library.uwGetter as Getter
 from pandas.core.frame import DataFrame
-from LibHanger.Library.uwExport import ExcelImporter
+from LibHanger.Library.uwImport import ExcelImporter
 
 class modelGenerator(ExcelImporter):
     
@@ -25,7 +27,7 @@ class modelGenerator(ExcelImporter):
         super().__init__()
         
         # フィールド型の対応クラス及びカラムタイプ定義
-        self.fieldTypeMap = {
+        self.fieldTypeMapPy = {
              'varchar':{'method':'CharFields','columnType':'String'}
             ,'numeric':{'method':'NumericFields','columnType':'Numeric'}
             ,'date':{'method':'DateFields','columnType':'Date'}
@@ -34,10 +36,10 @@ class modelGenerator(ExcelImporter):
             ,'double':{'method':'FloatFields','columnType':'Float'}
         }
         
-    def put_modelByCsv(self):
+    def put_modelToPython(self):
         
         """
-        モデル⇒Csvファイル出力
+        モデル⇒Pythonファイル出力
 
         Parameters
         ----------
@@ -51,7 +53,28 @@ class modelGenerator(ExcelImporter):
                 df = self.get_TableDefByDataFrame(sheetname)
                 # Model内容をpythonファイル出力
                 self.put_modelPython(df, sheetname)
-                   
+    
+    def put_modelToSql(self):
+        
+        """
+        モデル⇒SQLファイル出力
+
+        Parameters   
+        ----------
+        None
+        
+        """
+        
+        # テーブル一覧リスト取得
+        dfTableList = self.get_TableListByDataFrame('テーブル一覧表')
+        
+        for sheetname in self.sheets:
+            if str(sheetname).startswith(('trn','mst')): 
+                # テーブル定義をDataFrameで取得
+                dfDef = self.get_TableDefByDataFrame(sheetname)
+                # Model内容をsqlファイル出力
+                self.put_modelTableCreateSql(dfDef, dfTableList, sheetname)
+        
     def get_TableDefByDataFrame(self, sheetname:str):
         
         """
@@ -128,9 +151,43 @@ class modelGenerator(ExcelImporter):
             データ型
         """
         
-        fieldTypeVal:dict = self.fieldTypeMap.get(defRow['datatype'])
+        fieldTypeVal:dict = self.fieldTypeMapPy.get(defRow['datatype'])
         return fieldTypeVal.get(valType)
         
+    def get_fieldType_val(self, defRow):
+        
+        """
+        テーブル定義のデータ型に対応するColumnType取得
+        
+        Parameters
+        ----------
+        defRow : Any
+            対象Series
+        valType : Any
+            データ型
+        """
+        
+        # 桁数指定があるかどうか
+        fldType = ''
+        if defRow['length'] != 0:
+            fldLength = []
+            fldLength.append(str(defRow['length']))
+            if defRow['digits'] != 0:                
+                fldLength.append(str(defRow['digits']))
+            
+            fldType = '\t {0}({1})'.format(defRow['datatype'], ','.join(fldLength))
+        else:
+            fldType = defRow['datatype']
+            
+        # デフォルト値指定があるかどうか
+        if defRow['default'] != '' and str(defRow['default']).isdigit():
+            fldType += ' DEFAULT {0}'.format(int(defRow['default']))
+        
+        # 改行付与
+        fldType += '\n'
+        
+        return fldType
+    
     def get_fieldType_args(self, defRow):
         
         """
@@ -174,4 +231,68 @@ class modelGenerator(ExcelImporter):
             fieldType.append(defaultFormat.format(default))
         return Getter.getListMargeString(',', fieldType)
 
-            
\ No newline at end of file
+    def get_TableListByDataFrame(self, sheetname:str):
+        
+        """
+        テーブル一覧シートをDataFrameに変換
+        
+        Parameters
+        ----------
+        sheetname : str
+            読込対象シート名
+        """
+        
+        # シートをdict型に変換
+        dict = pd.read_excel(self.filepath, sheet_name=sheetname, skiprows=5, usecols=[7,8])
+        # dict->DataFrame
+        df = pd.DataFrame(dict)
+        # DataFrameの列名変更
+        df = df.set_axis(['schema','tablename'], axis='columns')
+        # 欠損値置換
+        df = df.fillna({'schema': '', 'tablename':''})
+        # DataFrameとして返す
+        return df[df['tablename'] != '']
+    
+    def put_modelTableCreateSql(self, dfDef:DataFrame, dfTableList:DataFrame, sheetname:str):
+        
+        """
+        ModelをTableCreateSQLファイルに出力
+        
+        Parameters
+        ----------
+        dfDef : DataFrame
+            テーブル定義DataFrame
+        dfTableList : DataFrame
+            テーブル一覧DataFrame
+        sheetname : str
+            読込対象シート名
+        """
+
+        # 出力先パス取得
+        output_dir = os.path.dirname(self.filepath)
+
+        # スキーマ取得
+        dfSchema = dfTableList[dfTableList['tablename'] == sheetname]
+        schema = ''
+        if len(dfSchema) > 0:
+            schema = dfSchema.iloc[0]['schema']
+        
+        # 主キー列取得
+        dfPrimary_key:pd.Series = dfDef[dfDef['primary_key'] !=0]['fieldname']
+        primary_key = []
+        if len(dfPrimary_key) > 0:
+            primary_key = dfPrimary_key.values.tolist()         
+        
+        # SQLファイル出力
+        with open(os.path.join(output_dir, sheetname + '.sql'), 'w', newline='', encoding='utf-8') as f:
+            f.writelines('create table {0}.{1} ('.format(schema, sheetname) + '\n')
+            for index, row in dfDef.iterrows():
+                print('LineNo={0}'.format(index))
+                comma = ' '
+                if index > 0:
+                    comma = ','
+                outputRow = '\t{0}{1}\t{2}'.format(comma, str(row['fieldname']), self.get_fieldType_val(row))
+                f.writelines(outputRow)
+            f.writelines('\t' + ',PRIMARY KEY({0})'.format(','.join(primary_key)) + '\n')
+            f.writelines(');' + '\n')
+        f.close()
\ No newline at end of file
